#=============================================================================
# Overview of build options:
#
# End of build options
#-----------------------------------------------------------------------------

##trace

# force single job compilation
%define _smp_mflags -j1
#%%global debug_package    %%{nil}
#%%global _lto_cflags      %%{nil}

%global gitdate          20241030
%global commit           c31e2f195e2a4bdd93a402e78a0f6919c2606972
%global shortcommit      %(c=%{commit}; echo ${c:0:7})

%global version          2.7
%global release          1

# set this to "1" if building a git/beta/rc release
%global beta_or_rc       1


#=============================================================================
# general
#-----------------------------------------------------------------------------
Name:           mamba
Version:        %{version}
%if %{beta_or_rc}
Release:        0.%{release}.%{gitdate}.git%{shortcommit}%{?dist}
%else
Release:        %{release}%{?dist}
%endif
Summary:        A Virtual Midi Keyboard for Jack Audio Connection Kit
License:        BSD
URL:            https://github.com/brummer10/Mamba
%if %{beta_or_rc}
# git clone --recurive //github.com/brummer10/Mamba.git
# do not update the submodules (git submodule update --recursive --remote)
# cd Mamba && ~/bin/git-archive-all.sh --format=tar.gz --prefix=Mamba/ --recursive --o ../Mamba-2.4-git5afea73.tar.gz
Source0:        https://github.com/brummer10/Mamba/archive/{commit}/Mamba-%{version}-git%{shortcommit}.tar.gz
%else
Source0:        https://github.com/brummer10/Mamba/archive/%{version}/Mamba-%{version}.tar.gz
%endif
BuildRequires:  alsa-lib-devel
BuildRequires:  cairo-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fluidsynth-devel
BuildRequires:  gcc-c++
BuildRequires:  liblo-devel
BuildRequires:  libsigc++20-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libsmf-devel
BuildRequires:  libX11-devel
BuildRequires:  pipewire-jack-audio-connection-kit-devel
BuildRequires:  vim-common
Requires:       pipewire-jack-audio-connection-kit

%description
A Virtual MIDI Keyboard and MIDI file player/recorder for Jack Audio
Connection Kit (build against pipewire).


#=============================================================================
# prep
#-----------------------------------------------------------------------------
%prep
%if %{beta_or_rc}
%autosetup -p1 -n Mamba
%else
%autosetup -p1 -n Mamba-%{version}
%endif


#=============================================================================
# build
#-----------------------------------------------------------------------------
%build
%make_build


#=============================================================================
# install
#-----------------------------------------------------------------------------
%install
%make_install

desktop-file-install --vendor '' \
        --add-category=X-Sound \
        --add-category=Midi \
        --add-category=X-Jack \
        --dir %{buildroot}/%{_datadir}/applications \
        %{buildroot}/%{_datadir}/applications/Mamba.desktop


#=============================================================================
# check
#-----------------------------------------------------------------------------
%check
desktop-file-validate %{buildroot}%{_datadir}/applications/Mamba.desktop


#=============================================================================
# files
#-----------------------------------------------------------------------------
%files
%defattr(-,root,root)
%license LICENSE
%doc README.md
%attr(0755,root,root)       %{_bindir}/%{name}
%attr(0644,root,root)       %{_datadir}/applications/Mamba.desktop
%attr(0644,root,root)       %{_datadir}/pixmaps/Mamba.svg


#=============================================================================
# changelog
#-----------------------------------------------------------------------------
%changelog
* Wed Oct 30 2024 Patrick Laimbock <patrick@laimbock.com> - 2.7-0.1
- update to git rev c31e2f195e2a4bdd93a402e78a0f6919c2606972

* Mon Apr 29 2024 Patrick Laimbock <patrick@laimbock.com> - 2.6-1
- update to version 2.6

* Sat May 06 2023 Patrick Laimbock <patrick@laimbock.com> - 2.4-0.6
- use git rev 5afea736b7dd649e3d704a88be9d9840039086b3
- rebuild against newer libsmf

* Thu Apr 20 2023 Patrick Laimbock <patrick@laimbock.com> - 2.4-0.5
- update to git rev 7cece39fd0e39844e0fd40ad5b0ada5080a73c8e
- fixes issue 51

* Thu Apr 20 2023 Patrick Laimbock <patrick@laimbock.com> - 2.4-0.4
- new try, add #include <string> to src/XAlsa.h

* Thu Apr 20 2023 Patrick Laimbock <patrick@laimbock.com> - 2.4-0.3
- update to git rev da913f2fa938027ac39da6cbde68beade2a79934
- another try to fix https://github.com/brummer10/Mamba/issues/51

* Thu Apr 20 2023 Patrick Laimbock <patrick@laimbock.com> - 2.4-0.2
- update to git rev 05aafdb2278b5f50b148c1ee25dc8cab8ffeee41
- fixes https://github.com/brummer10/Mamba/issues/51

* Sun Aug 21 2022 Patrick Laimbock <patrick@laimbock.com> - 2.4-0.1
- initial release of git rev 4ca6cefee3cda8e1d62e6de3e53c6f1211d114c2

